fn primitive_property<'tcx>(
property: &Property<'tcx>,
kind: PropertyKind,
) -> Property<'tcx>Expand description
Reuse the original arguments while checking one primitive component.
fn primitive_property<'tcx>(
property: &Property<'tcx>,
kind: PropertyKind,
) -> Property<'tcx>Reuse the original arguments while checking one primitive component.